#!/bin/sh
# baptiste@mailoo.org
# usage : $0 device_name node_name add|remove
# exemple : $0 sdb1 /dev/sdb1 add

if [ $# -ne 3 ] ; then
    printf "Usage : $0 device_name node_name add|remove\n"
    printf "Exemple : $0 sdb1 /dev/sdb1 add\n\n"
    exit 5
fi

# Si le device est déjà monté, on s'arrête tout de suite
# if mount | grep -q $1 > dev/null ; then
    # exit 2
# fi

# Récupérer le nom d'utilisateur connecté sur la session graphique (bourrin)
# ck-list-sessions est une daube
RUNNING_USER=`whoami`
SELECTED_USER=`ps aux | grep -e openbox -e gnome -e session-manager -e screensaver -e xfce -e lxpanel -e gvfs | awk '{print $1}' | sort | uniq | sed "/$RUNNING_USER/d" | head -1`
if [ "$SELECTED_USER" = "" ] ; then
    exit 0
fi
USERID=`id -u $SELECTED_USER`
GRPID=`id -g $SELECTED_USER`

# Définition des variables par défaut
VFSTYPE=auto
MNTNAME=$1
MNTPNT="/home/$SELECTED_USER/media"

# détermination du FS
MY_TYPE=`/sbin/blkid -c /dev/null -s TYPE -o value $2`
if [ "$MY_TYPE" = "" ] ; then
    VFSTYPE=auto
else
    VFSTYPE="$MY_TYPE"
fi

# détermination du point de montage
MY_LABEL=`/sbin/blkid -c /dev/null -s LABEL -o value $2`
if [ "$MY_LABEL" = "" ] ; then
    MNTNAME=$1
else
    MNTNAME=$(echo $MY_LABEL | tr ' ' '_')
fi

# détermination de l'UUID
MY_UUID=`/sbin/blkid -c /dev/null -s UUID -o value $2`

# on vérifie que le point de montage n'est pas déjà utilisé
# s'il l'est on redéfinit le point de montage à $MNTPNT/$device_name qui est unique
if $(/bin/mountpoint -q $MNTPNT/$MNTNAME) ; then
    MNTNAME=$1
fi

date >> /tmp/dev_usb
echo $3 >> /tmp/dev_usb
echo $1 $VFSTYPE >> /tmp/dev_usb
echo $MNTPNT/$MNTNAME  >> /tmp/dev_usb
echo "----------">> /tmp/dev_usb

# Action ADD
if [ "$3" = "add" ] ; then
    while [ -f /tmp/__insertusb ] ; do  /bin/true ; done
    touch  /tmp/__insertusb
    # On vérifie que la ligne n'existe pas déjà dans le fstab
    if ! grep -q -e "UUID=$MY_UUID" -e "LABEL=$MY_LABEL" -e "$2" /etc/fstab > /dev/null ; then
	# Création du point de montage
	mkdir -p $MNTPNT/$MNTNAME
	echo "#$1" >> /etc/fstab
	if grep -q "$2 " /etc/fstab > /dev/null ; then
	    echo -n "#" >> /etc/fstab
	fi
	# if [ "$VFSTYPE" = "ntfs" ] ; then 
	    # VFSTYPE=ntfs-3g
	    # chmod 777 `echo $MNTPNT/$MNTNAME | tr ' ' '_'`
	# fi
	echo $2 $MNTPNT/$MNTNAME $VFSTYPE users,noauto,defaults,uid=$USERID,gid=$GRPID 0 0 >> /etc/fstab
	mount $2
    fi
    rm /tmp/__insertusb
fi


# Action REMOVE
if [ "$3" = "remove" ] ; then
    while [ -f /tmp/fstab_mod ] ; do  /bin/true ; done
    touch /tmp/fstab_mod
    OLDMNTPATH=`grep /dev/$1 /etc/fstab | awk '{print $2}'`
    umount -f /dev/$1
    /bin/rmdir `echo $OLDMNTPATH | tr ' ' '_'`
    sed -i "/$1/d" /etc/fstab
  rm /tmp/fstab_mod
fi

exit 0
